@@ -23,7 +23,7 @@
 #include "octalbytecodec.h"
 
 // Qt
-#include <QtCore/QString>
+#include <QString>
 
 
 namespace Okteta
