@@ -28,7 +28,7 @@
 #include "testpiecetablechange.h"
 #include <piecetable/piecetable.h>
 // Qt
-#include <QtTest/QtTest>
+#include <QTest>
 
 
 namespace KPieceTable
