@@ -29,13 +29,13 @@
 #include "controller/dropper.h"
 #include "kcursor.h"
 // Okteta core
-#include <valuecodec.h>
+#include <okteta/valuecodec.h>
 // Qt
 #include <QStyle>
 #include <QFontDatabase>
-#include <QtGui/QPainter>
+#include <QPainter>
 #include <QScrollBar>
-#include <QtCore/QEvent>
+#include <QEvent>
 
 
 namespace Okteta
