@@ -23,11 +23,11 @@
 #include "selectrangetool.h"
 
 // lib
-#include <bytearrayview.h>
-#include <bytearraydocument.h>
+#include <kasten/okteta/bytearrayview.h>
+#include <kasten/okteta/bytearraydocument.h>
 // Okteta core
-#include <abstractbytearraymodel.h>
-#include <arraychangemetricslist.h>
+#include <okteta/abstractbytearraymodel.h>
+#include <okteta/arraychangemetricslist.h>
 // KF5
 #include <KLocalizedString>
 
