@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2010,2014 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -22,40 +22,47 @@
 
 #include "bytespergroupdialog.h"
 
-// KDE
-#include <KIntNumInput>
-#include <KLocale>
+// KF5
+#include <KLocalizedString>
 // Qt
-#include <QtGui/QFormLayout>
+#include <QFormLayout>
+#include <QVBoxLayout>
+#include <QSpinBox>
+#include <QDialogButtonBox>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 BytesPerGroupDialog::BytesPerGroupDialog( QWidget* parent )
-  : KDialog( parent )
+  : QDialog( parent )
 {
-    QWidget* page = new QWidget( this );
-    setMainWidget( page );
+    QFormLayout* pageLayout = new QFormLayout();
 
-    QFormLayout* pageLayout = new QFormLayout( page );
-    pageLayout->setMargin( 0 );
-
-    mGroupedBytesCountEdit = new KIntNumInput( this );
+    mGroupedBytesCountEdit = new QSpinBox( this );
     mGroupedBytesCountEdit->setRange( 0, INT_MAX );
-    mGroupedBytesCountEdit->setSuffix( ki18np(" byte"," bytes") );
     const QString noGroupingText = i18nc( "@label",
                                           "No grouping." );
     mGroupedBytesCountEdit->setSpecialValueText( noGroupingText );
     const QString groupedBytesCountLabel =
         i18nc( "@label:spinbox number of bytes which are grouped",
-               "Per Group:" );
+               "Bytes per Group:" );
     pageLayout->addRow( groupedBytesCountLabel, mGroupedBytesCountEdit );
 
+    QDialogButtonBox* dialogButtonBox = new QDialogButtonBox;
+    dialogButtonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+
+    QVBoxLayout* layout = new QVBoxLayout;
+
+    layout->addLayout(pageLayout);
+    layout->addWidget(dialogButtonBox);
+    setLayout(layout);
+
     const QString caption =
         i18nc("@title:window","Bytes per Group");
-    setCaption( caption );
-    setButtons( Ok | Cancel );
+    setWindowTitle( caption );
 }
 
 int BytesPerGroupDialog::groupedBytesCount() const { return mGroupedBytesCountEdit->value(); }
