@@ -25,9 +25,9 @@
 // lib
 #include "bytesperlinedialog.h"
 #include "bytespergroupdialog.h"
-#include <bytearrayview.h>
+#include <kasten/okteta/bytearrayview.h>
 // Okteta core
-#include <charcodec.h>
+#include <okteta/charcodec.h>
 // KF5
 #include <KXMLGUIClient>
 #include <KLocalizedString>
