@@ -23,15 +23,15 @@
 #include "bytearrayrowscolumntextrenderer.h"
 
 // Okteta core
-#include <valuecodec.h>
-#include <charcodec.h>
-#include <character.h>
-#include <abstractbytearraymodel.h>
+#include <okteta/valuecodec.h>
+#include <okteta/charcodec.h>
+#include <okteta/character.h>
+#include <okteta/abstractbytearraymodel.h>
 // Qt
-#include <QtCore/QTextStream>
+#include <QTextStream>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 ByteArrayRowsColumnTextRenderer::ByteArrayRowsColumnTextRenderer( const Okteta::AbstractByteArrayModel* byteArrayModel,
